<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Aktivigi la kromprogramon',
	'affichage' => 'Afiŝado',
	'aide_non_disponible' => 'Tiu ĉi parto de la rethelpilo ankoraŭ ne disponeblas en tiu ĉi lingvo.',
	'annuler_recherche' => 'Nuligi serĉon',
	'auteur' => 'Aŭtoro :',
	'avis_acces_interdit' => 'Malpermesata aliro.',
	'avis_article_modifie' => 'Atentu, @nom_auteur_modif@ laboris pri tiu artikolo antaŭ @date_diff@ minutoj',
	'avis_aucun_resultat' => 'Neniu rezulto.',
	'avis_base_inaccessible' => 'Ne eblas konektiĝi al la datumbazo @base@.',
	'avis_chemin_invalide_1' => 'La alirvojo, kiun vi elektis, ',
	'avis_chemin_invalide_2' => 'ne ŝajnas taŭgi. Bonvolu reveni al la antaŭa paĝo kaj kontroli la entajpitajn datenojn.',
	'avis_connexion_echec_1' => 'Konektiĝo al SQL-servilo malsukcesis.',
	'avis_connexion_echec_2' => 'Revenu al la antaŭa paĝo, kaj kontrolu entajpitajn datenojn.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Ĉe multaj serviloj, vi devas <b>peti</b> aktivigon de via aliro al SQL-datumbazo antaŭ ol uzi ĝin. Se vi ne povas konektiĝi, kontrolu ke vi ja faris tiun ĉi demarŝon.',
	'avis_connexion_erreur_creer_base' => 'La datenbazo ne povis esti kreita.',
	'avis_connexion_erreur_nom_base' => 'La nomo de la datumbazo enhaveblas nur literoj, ciferoj kaj haltostrekoj',
	'avis_connexion_ldap_echec_1' => 'Konektiĝo al LDAP-servilo malsukcesis.',
	'avis_connexion_ldap_echec_2' => 'Revenu al la antaŭa paĝo, kaj kontrolu la entajpitajn datenojn. ',
	'avis_connexion_ldap_echec_3' => 'Eventuale, provu ne uzi LDAP-materialon por importi uzantojn.', # MODIF
	'avis_deplacement_rubrique' => 'Atentu ! Tiu ĉi rubriko enhavas @contient_breves@ fulm-informon @scb@ : se vi translokas ĝin, bonvolu noĉi tiun por-konfirman noĉujon. ',
	'avis_erreur_connexion_mysql' => 'SQL-konekta eraro ',
	'avis_espace_interdit' => '<b>Malpermesata aliro</b> <div>SPIP jam estas instalita.</div>',
	'avis_lecture_noms_bases_1' => 'Instalprogramo ne sukcesis legi la nomojn de la instalitaj datenbazoj.',
	'avis_lecture_noms_bases_2' => 'Aŭ neniu datenbazo disponeblas, aŭ la funkcio ebliganta listigi datenbazojn estis malaktivigita pro sekuraj kialoj (tio ja okazas ĉe multaj retejoj-gastigantoj).',
	'avis_lecture_noms_bases_3' => 'Okaze de la dua alternativo, eble uzeblos datenbazo nomita per via salutnomo :',
	'avis_non_acces_page' => 'Vi ne havas alir-rajton al tiu paĝo.',
	'avis_operation_echec' => 'La ago malsukcesis.',
	'avis_operation_impossible' => 'Faro ne ebla',
	'avis_suppression_base' => 'ATENTU, forviŝo de datenoj estas definitiva',

	// B
	'bouton_acces_ldap' => 'Aldoni aliron al LDAP',
	'bouton_ajouter' => 'Aldoni',
	'bouton_annuler' => 'Nuligi',
	'bouton_cache_activer' => 'Reaktivigi la staplon',
	'bouton_cache_desactiver' => 'Malaktivigi maldaŭre la staplon',
	'bouton_demande_publication' => 'Peti publikigon de tiu ĉi artikolo',
	'bouton_desactive_tout' => 'Ĉion malaktivigi',
	'bouton_desinstaller' => 'Malinstali',
	'bouton_effacer_tout' => 'Forviŝi ĈION',
	'bouton_envoyer_message' => 'Definitiva mesaĝo : sendi',
	'bouton_fermer' => 'Fermi',
	'bouton_mettre_a_jour' => 'Ĝisdatigi',
	'bouton_mettre_a_jour_base' => 'Ĝisdatigi la datumbazo',
	'bouton_modifier' => 'Modifi',
	'bouton_radio_afficher' => 'Afiŝi',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aperi en la listo de konektitaj redaktantoj', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Sendi la anoncojn al jena adreso :',
	'bouton_radio_envoi_liste_nouveautes' => 'Sendi la novaĵoj-liston',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ne aperi en la listo de redaktantoj', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Ne sendi anoncojn pri ĉefartikoloj',
	'bouton_redirection' => 'ALIDIREKTIGO',
	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Restarigi laŭ defaŭltaj valoroj',
	'bouton_relancer_installation' => 'Relanĉi la instaladon',
	'bouton_reset_password' => 'Krei novan pasvorton, kaj sendi ĝin retpoŝte',
	'bouton_suivant' => 'Sekvanta',
	'bouton_tenter_recuperation' => 'Provi riparon',
	'bouton_test_proxy' => 'Provi la prokuran servilon',
	'bouton_vider_cache' => 'Malplenigi la staplon',

	// C
	'cache_modifiable_webmestre' => 'Tiun parametron povas modifi la retejestro.', # MODIF
	'calendrier_synchro' => 'Se vi uzas temp-organizan bitvaron kongruan kun <b>iCal</b> formato, vi povas ĝisdatigi tiun lastan laŭ la datenoj de tiu ĉi retejo.',
	'config_activer_champs' => 'Ŝalti la jenajn kampojn',
	'config_choix_base_sup' => 'indiki datumbazon ĉe tiu ĉi servilo',
	'config_erreur_base_sup' => 'SPIP ne havas alireblon al listo de alireblaj bazoj',
	'config_info_base_sup' => 'Se vi havas aliajn datumbazojn por pridemandi tra SPIP, pere de ĝia SQL-servilo aŭ de alia servilo, la ĉi-suba formularo ebligas al vi ilin deklari. Se vi lasas tajpujojn malplenaj, la ensalutiloj al la ĉefa datumbazo estos uzitaj.',
	'config_info_base_sup_disponibles' => 'Jam pridemandeblaj kromaj datumbazoj :',
	'config_info_enregistree' => 'La nova agordo estas registrita',
	'config_info_logos' => 'Ĉiu elemento de la retejo povas havi vinjeton, kaj « flugrigardeblajn vinjeton »',
	'config_info_logos_utiliser' => 'Uzi la vinjetojn',
	'config_info_logos_utiliser_non' => 'Ne uzi la vinjetojn',
	'config_info_logos_utiliser_survol' => 'Uzi la flugrigardajn vinjetojn',
	'config_info_logos_utiliser_survol_non' => 'Ne uzi la flugrigardeblajn vinjetojn',
	'config_info_redirection' => 'Se vi ŝaltas tiun ĉi opcion, vi povos krei virtualajn artikolojn, simplajn referencojn pri artikoloj publikigitaj ĉe aliaj retejoj aŭ ekster SPIP.',
	'config_redirection' => 'Virtualaj artikoloj',
	'config_titre_base_sup' => 'Deklaro de kroma datumbazo',
	'config_titre_base_sup_choix' => 'Elektu kroman datumbazon',
	'connexion_ldap' => 'Konektiĝo :',
	'creer_et_associer_un_auteur' => 'Krei kaj ligi aŭtoron',

	// D
	'date_mot_heures' => 'horoj',

	// E
	'ecran_securite' => ' + sekuriga ŝirmilo @version@',
	'email' => 'retpoŝtadreso',
	'email_2' => 'retpoŝtadreso :',
	'en_savoir_plus' => 'Pli scii tion',
	'entree_adresse_annuaire' => 'Adreso al la dosierujilo',
	'entree_adresse_email' => 'Via retpoŝtadreso',
	'entree_adresse_email_2' => ' Retpoŝtadreso',
	'entree_base_donnee_1' => 'Adreso de la datenbazo',
	'entree_base_donnee_2' => '(Tiu adreso ofte estas tiu de via retejo, foje estas "localhost", alifoje la entajpujo restas malplena.)',
	'entree_biographie' => 'Mallonga kelkvorta biografio.',
	'entree_chemin_acces' => '<b>Entajpi</b> alirvojon :',
	'entree_cle_pgp' => 'Via PGP-ŝlosilo ',
	'entree_cle_pgp_2' => 'PGP-ŝlosilo',
	'entree_contenu_rubrique' => '(Enhavo de la rubriko per kelkaj vortoj.)',
	'entree_identifiants_connexion' => 'Viaj ensalutiloj...',
	'entree_identifiants_connexion_2' => 'Ensalutiloj',
	'entree_informations_connexion_ldap' => 'En tiun formularon, bonvolu entajpi informojn por konekti al via LDAP-dosierujilo. Tiujn informojn disponigu al vi la sistema aŭ reta mastrumanto.', # MODIF
	'entree_infos_perso' => 'Kiu vi estas ?',
	'entree_infos_perso_2' => 'Kiu estas la aŭtoro ?',
	'entree_interieur_rubrique' => 'En la rubriko :',
	'entree_liens_sites' => '<b>Hiperligilo</b> (referenco, vizitinda retejo...)',
	'entree_login' => 'Via salutnomo',
	'entree_login_connexion_1' => 'La salutnomo',
	'entree_login_connexion_2' => '(Foje estas via salutnomo por eniri la FTP-ejon ; foje ĝi restas malplena)',
	'entree_mot_passe' => 'Via pasvorto',
	'entree_mot_passe_1' => 'La pasvorto por ensaluti',
	'entree_mot_passe_2' => '(Foje estas via pasvorto por la FTP-ejo ; foje ĝi restas malplena)',
	'entree_nom_fichier' => 'Bonvolu entajpi la dosieran nomon @texte_compresse@ :',
	'entree_nom_pseudo' => 'Via nomo aŭ via kromnomo',
	'entree_nom_pseudo_1' => '(Via nomo aŭ via kromnomo)',
	'entree_nom_pseudo_2' => 'Nomo aŭ kromnomo',
	'entree_nom_site' => 'La nomo de via retejo',
	'entree_nom_site_2' => 'retejnomo de la aŭtoro',
	'entree_nouveau_passe' => 'Nova pasvorto',
	'entree_passe_ldap' => 'Pasvorto',
	'entree_port_annuaire' => 'Numero de la dosierujila pordo',
	'entree_signature' => 'Subskribo',
	'entree_titre_obligatoire' => '<b>Titolo</b> [Deviga]<br />',
	'entree_url' => 'Retadreso de via retejo',
	'entree_url_2' => 'Retadreso de la retejo',
	'erreur_connect_deja_existant' => 'Servilo jam ekzistas kun tiu nomo',
	'erreur_contenu_suspect' => 'Teksto kun ne aktivaj HTML-markoj',
	'erreur_email_deja_existant' => 'Tiu retpoŝtadreso jam estas registrita.',
	'erreur_nom_connect_incorrect' => 'Tiu servilonomo ne estas permesita',
	'erreur_plugin_attribut_balise_manquant' => 'Atributo @attribut@ mankas en la marko @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'La malinstalo de la kromprogramo malsukcesis.
Tamen vi povas malŝalti ĝin.',
	'erreur_plugin_fichier_absent' => 'Foresta dosiero',
	'erreur_plugin_fichier_def_absent' => 'Difina dosiero forestas',
	'erreur_plugin_nom_fonction_interdit' => 'Malpermesata funkcio-nomo',
	'erreur_plugin_nom_manquant' => 'Kromprogramo-nomo mankas',
	'erreur_plugin_prefix_manquant' => 'Nedifinita nom-spaco de kromprogramo',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; mankas en tiu difina dosiero',
	'erreur_plugin_version_manquant' => 'Kromprogramo-versio mankas',

	// H
	'htaccess_a_simuler' => 'Averto : la agordo de vian HTTP-servilo ignoras dosierojn @htaccess@. Por certigi taŭgan sekureco, vi devas ŝanĝi la agordon pri tio, aŭ ke konstantoj @constantes@ (difinebla en la dosiero mes_options.php) havas kiel valoro dosierujojn ekstere de @document_root@.',
	'htaccess_inoperant' => 'senefika htaccess',

	// I
	'ical_info1' => 'Tiu paĝo prezentas plurajn metodojn por daŭre ricevi informojn pri la vivo de tiu retejo.',
	'ical_info2' => 'Por pli da informoj pri ĉi ĉiuj teknikoj, senhezite konsultu <a href="@spipnet@">la dokumentaron de SPIP</a>.',
	'ical_info_calendrier' => 'Du kalendaroj disponeblas. La unua estas retejo-mapo anoncanta ĉiujn publikigitajn artikolojn. La dua enhavas la eldon-anoncojn, kaj viajn lastajn privatajn mesaĝojn : ĝi estas rezervita al vi, pere de persona ŝlosilo, kiun vi ĉiumomente povas modifi ŝanĝante vian pasvorton.',
	'ical_methode_http' => 'Elŝuti',
	'ical_methode_webcal' => 'Sinkroniga ĝisdatigo (webcal://)',
	'ical_texte_prive' => 'Tiu ĉi strikte persona kalendaro, informas vin pri la privataj eldonoj de la retejo (personaj taskoj kaj rendevuoj, proponitaj artikoloj kaj fulm-informoj...).',
	'ical_texte_public' => 'Per tiu ĉi kalendaro, vi povas gvati la publikan funkciadon de tiu retejo (publikigitaj fulm-informoj kaj artikoloj).',
	'ical_texte_rss' => 'Vi povas abonŝuti la novaĵojn el tiu ĉi retejo al kiu ajn XML/RSS-legilo. Estas tiu formato, kiu ankaŭ ebligas al SPIP legi la novaĵojn publikigitajn ĉe aliaj retejoj, kiuj uzas kongruan formaton (aliaj abonligitaj retejoj).',
	'ical_titre_js' => 'Ĝavaskripto',
	'ical_titre_mailing' => 'Dissendlisto',
	'ical_titre_rss' => 'Abonligoj',
	'icone_accueil' => 'Hejmpaĝo',
	'icone_activer_cookie' => 'Aktivigi la korespond-kuketon',
	'icone_activite' => 'Aktiveco',
	'icone_admin_plugin' => 'Mastrumado de kromprogramoj',
	'icone_administration' => 'Bontenado',
	'icone_afficher_auteurs' => 'Afiŝi la aŭtorojn',
	'icone_afficher_visiteurs' => 'Afiŝi la vizitantojn',
	'icone_arret_discussion' => 'Ne plu partopreni en ĉi tiu diskuto',
	'icone_calendrier' => 'Kalendaro',
	'icone_configuration' => 'Agordo',
	'icone_creer_auteur' => 'Krei novan aŭtoron kaj ligi ŝlin al tiu artikolo',
	'icone_creer_mot_cle' => 'Krei novan ŝlosilvorton kaj ligi ĝin al tiu artikolo',
	'icone_creer_rubrique_2' => 'Krei novan rubrikon',
	'icone_developpement' => 'Programado',
	'icone_edition' => 'Eldono',
	'icone_ma_langue' => 'Mia lingvo',
	'icone_mes_infos' => 'Miaj informoj',
	'icone_mes_preferences' => 'Miaj preferoj',
	'icone_modifier_article' => 'Modifi tiun ĉi artikolon',
	'icone_modifier_rubrique' => 'Modifi tiun ĉi rubrikon',
	'icone_publication' => 'Publikigo',
	'icone_relancer_signataire' => 'Reinstigi tiun ĉi subskribinton',
	'icone_retour' => 'Reen',
	'icone_retour_article' => 'Reen al la artikolo',
	'icone_squelette' => 'Skeletoj',
	'icone_suivi_publication' => 'Superrigardo de la publikigo',
	'icone_supprimer_cookie' => 'Forviŝi la por-korespondan kuketon ',
	'icone_supprimer_rubrique' => 'Forviŝi tiun rubrikon',
	'icone_supprimer_signature' => 'Forviŝi tiun subskribon',
	'icone_valider_signature' => 'Validigi tiun subskribon',
	'image_administrer_rubrique' => 'Vi povas mastrumi tiun rubrikon',
	'impossible_modifier_login_auteur' => 'Ne eblas modifi la salutnomo.', # MODIF
	'impossible_modifier_pass_auteur' => 'Ne eblas modifi la pasvorto.', # MODIF
	'info_1_article' => '1 artikolo',
	'info_1_auteur' => '1 aŭtoro',
	'info_1_message' => '1 mesaĝo',
	'info_1_mot_cle' => '1 ŝlosilvorto',
	'info_1_rubrique' => '1 rubriko',
	'info_1_visiteur' => '1 vizitanto',
	'info_activer_cookie' => 'Vi povas aktivigi <b>por-korespondan kuketon</b>. Tio ebligos al vi facile iri de la publika spaco al la privata.',
	'info_activer_menu_developpement' => 'Montri la menuon Programado',
	'info_admin_etre_webmestre' => 'Doni al mi la rajtoj de retejestro',
	'info_admin_je_suis_webmestre' => 'Mi estas <b>retejestro</b>',
	'info_admin_statuer_webmestre' => 'Doni al tiu mastrumanto la rajtoj de retejestro', # MODIF
	'info_admin_webmestre' => 'Tiu mastrumanto estas <b>retejestro</b>', # MODIF
	'info_administrateur' => 'Mastrumanto', # MODIF
	'info_administrateur_1' => 'Mastrumanto', # MODIF
	'info_administrateur_2' => 'de la retejo (<i>uzi singarde</i>)',
	'info_administrateur_site_01' => 'Se vi estas mastrumanto de la retejo, bonvolu', # MODIF
	'info_administrateur_site_02' => 'musklaki ĉi-tiun ligilon',
	'info_administrateurs' => 'Mastrumantoj', # MODIF
	'info_administrer_rubrique' => 'Vi povas mastrumi tiun rubrikon',
	'info_adresse' => 'ĉe la adreso :',
	'info_adresse_desinscription' => 'Adreso de malregistriĝo',
	'info_adresse_url' => 'Retadreso (URL) de la publika retejo',
	'info_afficher_par_nb' => 'Afiŝi per',
	'info_aide_en_ligne' => 'Reta SPIP-helpilo',
	'info_ajout_image' => 'Kiam vi ligas bildojn kiel alkroĉitajn dokumentojn al artikolo,
 SPIP povas aŭtomate krei por vi etajn vinjetojn de la
 enmetitaj bildoj. Tio ebligas ekzemple, aŭtomate krei bildaron, ĉu en sukcesiva, ĉu samtempa ordo.',
	'info_ajouter_rubrique' => 'Aldoni alian mastrumendan rubrikon :',
	'info_annonce_nouveautes' => 'Anonco pri novaĵoj',
	'info_article' => 'artikolo',
	'info_article_2' => 'artikoloj',
	'info_article_a_paraitre' => 'Aperotaj post-datitaj artikoloj',
	'info_articles_02' => 'artikoloj',
	'info_articles_2' => 'Artikoloj',
	'info_articles_auteur' => 'La artikoloj de tiu aŭtoro',
	'info_articles_miens' => 'Miaj artikoloj',
	'info_articles_tous' => 'Ĉiuj la artikoloj',
	'info_articles_trouves' => 'Trovitaj artikoloj',
	'info_attente_validation' => 'Viaj artikoloj atendantaj validigon',
	'info_aucun_article' => 'Neniu artikolo',
	'info_aucun_auteur' => 'Neniu aŭtoro',
	'info_aucun_message' => 'Neniu mesaĝo',
	'info_aucun_rubrique' => 'Neniu rubriko',
	'info_aujourdhui' => 'hodiaŭ : ',
	'info_auteur_gere_rubriques' => 'Tiu aŭtoro mastrumas la jenajn rubrikojn :',
	'info_auteur_gere_toutes_rubriques' => 'Tiu aŭtoro mastrumas <b>ĉiujn rubrikojn</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Mi mastrumas <b>ĉiujn rubrikojn</b>',
	'info_auteurs' => 'La aŭtoroj',
	'info_auteurs_par_tri' => 'Aŭtoroj@partri@',
	'info_auteurs_trouves' => 'Aŭtoroj trovitaj',
	'info_authentification_externe' => 'Ekstera aŭtentigo',
	'info_avertissement' => 'Averto',
	'info_barre_outils' => 'ĉu per ĝia ilobreto ?',
	'info_base_installee' => 'La strukturo de via datenbazo estas instalita.',
	'info_bio' => 'Biografio',
	'info_cache_desactive' => 'La staplo estas maldaŭre malaktivigita.',
	'info_chapeau' => 'Ĉapo',
	'info_chapeau_2' => 'Ĉapo :',
	'info_chemin_acces_1' => 'Opcioj : <b>Alirvojo en la LDAP-dosierujilo</b>',
	'info_chemin_acces_2' => 'Ekde nun vi devas konfiguri la alirvojon al la LDAP-dosierujilo. Tiu informo estas nepre necesa por legi la profilojn de uzantoj stokataj en la dosierujilo.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcioj : <b>Aliro en la LDAP-dosierujilo',
	'info_choix_base' => 'Tria etapo : ',
	'info_classement_1' => '<sup>a</sup> en @liste@',
	'info_classement_2' => '<sup>a</sup> en @liste@',
	'info_code_acces' => 'Ne forgesu viajn proprajn alir-kodojn !',
	'info_config_suivi' => 'Se tiu ĉi adreso estas tiu de dissendlisto, indiku ĉi-sube la adreson ĉe kiu la partoprenantoj de la retejo povos registriĝi. Tiu adreso povas esti retligilo (ekz. la paĝo por rete registriĝi en la listo), aŭ retpoŝtadreso kun specifa temo (ekz. <tt>@adresse_suivi@?subject=registrigxi</tt>) :',
	'info_config_suivi_explication' => 'Vi povas aboni la dissendliston de tiu ĉi retejo. Aboninta, vi ricevos per retmesaĝoj la anoncojn pri artikoloj kaj pri fulm-informoj proponitaj por publikigo.',
	'info_confirmer_passe' => 'Konfirmi tiun novan pasvorton :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atentu, la jenaj tajpujoj estis iel modifitaj. Sekve, viaj ŝanĝoj en tiuj ĉi tajpujoj ne estas registritaj.',
	'info_conflit_edition_differences' => 'Malsamecoj :',
	'info_conflit_edition_version_enregistree' => 'La registrita versio :',
	'info_conflit_edition_votre_version' => 'Via versio :',
	'info_connexion_base' => 'Dua etapo : <b>Konektiĝo-provo al la datenbazo</b>',
	'info_connexion_base_donnee' => 'Konektiĝo al via datumbazo',
	'info_connexion_ldap_ok' => '<b>La konektiĝo al LDAP sukcesis.</b><p>Vi povas iri al la sekvanta etapo</p>',
	'info_connexion_mysql' => 'Via SQL-konektiĝo',
	'info_connexion_ok' => 'La konektiĝo sukcesis.',
	'info_contact' => 'Kontakt-adreso',
	'info_contenu_articles' => 'Enhavo de la artikoloj',
	'info_contributions' => 'Kontribuaĵoj',
	'info_creation_paragraphe' => 'Por krei malplenajn paragrafojn, simple lasu malplenajn liniojn.',
	'info_creation_rubrique' => 'Antaŭ ol skribi artikolojn,<br /> vi kreu almenaŭ po unu rubrikon.<br />',
	'info_creation_tables' => 'Kreo de la datentabeloj',
	'info_creer_base' => '<b>Krei</b> novan datenbazon :',
	'info_dans_rubrique' => 'En la rubriko :',
	'info_date_publication_anterieure' => 'Dato de antaŭa redakto :',
	'info_date_referencement' => 'REFERENCIGO-DATO DE TIU RETEJO :',
	'info_derniere_etape' => 'Finite !',
	'info_descriptif' => 'Priskribo :',
	'info_desinstaller_plugin' => 'forviŝas la datenojn kaj malaktivigas la kromprogramon',
	'info_discussion_cours' => 'Nunaj diskutoj',
	'info_ecrire_article' => 'Antaŭ ol ekhavi la eblon skribi artikolojn, vi devas krei almenaŭ unu rubrikon.',
	'info_email_envoi' => 'retpoŝtadreso por sendo (nedeviga)',
	'info_email_envoi_txt' => 'Indiku ĉi tie la adreson uzotan por sendi poŝtmesaĝojn (defaŭlte, la ricev-adreso estos uzata) :',
	'info_email_webmestre' => 'Retpoŝtadreso de la retejestro', # MODIF
	'info_envoi_email_automatique' => 'Aŭtomata retleteroj-dissendado',
	'info_envoyer_maintenant' => 'Sendu nun',
	'info_etape_suivante' => 'Ek al posta etapo',
	'info_etape_suivante_1' => 'Vi povas paŝi al posta etapo.',
	'info_etape_suivante_2' => 'Vi povas paŝi al posta etapo.',
	'info_exceptions_proxy' => 'Escepto por la prokura servilo',
	'info_exportation_base' => 'Eksporto de la datenbazo al @archive@',
	'info_facilite_suivi_activite' => 'Por faciligi la kontrolon de la reteja ĉefartikola aktiveco, SPIP povas transdoni per retmesaĝoj - ekzemple al dissendlisto de redaktantoj - la anoncon pri publikig-petoj kaj validig-petoj de artikoloj.', # MODIF
	'info_fichiers_authent' => 'Aŭtentokontrolaj dosieroj « .htpasswd »',
	'info_forums_abo_invites' => 'Via retejo enhavas forumojn alireblajn nur per abono ; vizitantoj estas invititaj al registriĝo ĉe la publika retejo.', # MODIF
	'info_gauche_admin_tech' => '<b>Nur respondeculoj de la retejo rajtas aliri tiun paĝon.</b><p>Ĝi ebligas aliron al la diversaj funkcioj pri teknika bontenado. Iuj el ili okazigas specifan aŭtentigan procezon, kiu
postulas disponi je FTP-alirrajto al la retejo.</p>',
	'info_gauche_auteurs' => 'Vi trovos ĉi tie ĉiujn aŭtorojn de la retejo. Ilia statuso estas indikita per koloro de sia piktogramo (mastrumanto = verda, redaktanto = flava).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'La eksteraj aŭtoroj, sen alireblo al la retejo, estas indikitaj per blua piktogramo ;
 la aŭtoroj forviŝitaj per griza piktogramo.',
	'info_gauche_messagerie' => 'La mesaĝilo ebligas al vi interŝanĝi mesaĝojn inter aŭtoroj, konservi memorigilojn (por via propra uzado) aŭ afiŝi anoncojn ĉe la hejmpaĝo de la privata spaco (se vi estas mastrumanto).', # MODIF
	'info_gauche_statistiques_referers' => 'Tiu paĝo prezentas la liston de la  <i>referencoj</i>, tio estas retejoj enhavantaj ligilojn al via propra retejo, nur koncerne hieraŭ kaj hodiaŭ : tiu listo estas prastatigita ĉiujn 24 horojn.',
	'info_gauche_visiteurs_enregistres' => 'Vi trovos ĉi tie la vizitantojn registritajn
 en la publika spaco de la retejo (forumoj laŭ abono).',
	'info_generation_miniatures_images' => 'Bildoj-miniaturigo',
	'info_gerer_trad_objets' => '@objets@ : mastrumi la traduk-ligilojn',
	'info_hebergeur_desactiver_envoi_email' => 'Iuj retgastigantoj malaktivigas la aŭtomatan retleteroj-sendadon ekde ties serviloj. Tiukaze, la jenaj SPIP-funkcioj ne fonkcios.',
	'info_hier' => 'hieraŭ :',
	'info_identification_publique' => 'Via publika identeco...',
	'info_image_process' => 'Bonvolu elekti la plej bonan metodon por fabriki vinjetojn musklakante laŭcele bildon.',
	'info_image_process2' => 'Se neniu bildo afiŝiĝas, tio signifas ke la servilo kiu gastigas vian retejon ne estas konfigurita por uzi tiajn ilojn. Se vi deziras uzi tiujn funkciojn, petu la « GD » aŭ « Imagick » modulojn al la teknika repondeculo.',
	'info_images_auto' => 'Bildoj aŭtomate komputitaj',
	'info_informations_personnelles' => 'Personaj datenoj',
	'info_inscription' => 'Registriĝado je',
	'info_inscription_automatique' => 'Aŭtomata registriĝado de novaj redaktantoj', # MODIF
	'info_jeu_caractere' => 'Litertiparo de la retejo',
	'info_jours' => 'tagoj',
	'info_laisser_champs_vides' => 'lasi tiujn tajpujojn malplenaj)',
	'info_langues' => 'Lingvoj de la retejo',
	'info_ldap_ok' => 'La LDAP-aŭtentokontrolilo estas instalita.',
	'info_lien_hypertexte' => 'Hiperligilo :',
	'info_liste_nouveautes_envoyee' => 'La listo de novaĵoj estis sendita',
	'info_liste_redacteurs_connectes' => 'Listo de la konektitaj redaktantoj', # MODIF
	'info_login_existant' => 'Tiu salutnomo jam ekzistas.',
	'info_login_trop_court' => 'Tro mallonga salutnomo.',
	'info_login_trop_court_car_pluriel' => 'La salutnomo devas enhavi almenaŭ @nb@ signojn.',
	'info_logos' => 'La vinjetoj',
	'info_maximum' => 'maksimumo :',
	'info_meme_rubrique' => 'En la sama rubriko',
	'info_message_en_redaction' => 'Viaj redaktataj mesaĝoj',
	'info_message_technique' => 'Teknika mesaĝo :',
	'info_messagerie_interne' => 'Interna mesaĝilo',
	'info_mise_a_niveau_base' => 'alniveligo de via SQL-datenbazo',
	'info_mise_a_niveau_base_2' => '{{Atentu !}} Vi ĵus instalis version de la SPIP-dosieroj {pli malnovan} ol tiun, kiu estis instalita antaŭe ĉe via retejo : eblas ke via datenbazo perdiĝos kaj ke via retejo ne plu funkcios.<br />{{Reinstalu la
 SPIP-dosierojn.}}',
	'info_modification_enregistree' => 'Via modifo estis registrita',
	'info_modifier_auteur' => 'Modifi tiun ĉi aŭtoron :',
	'info_modifier_rubrique' => 'Modifi la rubrikon :',
	'info_modifier_titre' => 'Modifi : @titre@',
	'info_mon_site_spip' => 'Mia SPIP-retejo',
	'info_moyenne' => 'meznombro :',
	'info_multi_cet_article' => 'Lingvo de tiu ĉi artikolo :',
	'info_multi_langues_choisies' => 'Bonvolu elekti ĉi-sube la lingvojn, kiujn vi volas disponigi al la redaktantoj de via retejo.
  Vi ne povas malaktivigi la lingvojn jam uzatajn (unue afiŝitajn) ĉe via retejo.', # MODIF
	'info_multi_objets' => '@objets@ : aktivigi la lingvomenuon',
	'info_multi_secteurs' => '... ĉu nur por la rubrikoj situantaj ĉe la radiko ?',
	'info_nb_articles' => '@nb@ artikoloj',
	'info_nb_auteurs' => '@nb@ aŭtoroj',
	'info_nb_messages' => '@nb@ mesaĝoj',
	'info_nb_mots_cles' => '@nb@ ŝlosilvortoj',
	'info_nb_rubriques' => '@nb@ rubrikoj',
	'info_nb_visiteurs' => '@nb@ vizitantoj',
	'info_nom' => 'Nomo',
	'info_nom_destinataire' => 'Nomo de la adresato',
	'info_nom_pas_conforme' => 'la HTML-markoj estas malpermesitaj',
	'info_nom_site' => 'Nomo de via retejo',
	'info_nombre_articles' => '@nb_articles@ artikoloj,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubrikoj,',
	'info_nombre_sites' => '@nb_sites@ retejoj,',
	'info_non_deplacer' => 'Ne transloki...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP povas regule sendi anoncon pri la lastaj novaĵoj de la retejo (artikolojn kaj fulm-informojn freŝe publikigitajn).',
	'info_non_envoi_liste_nouveautes' => 'Ne sendi la liston de la novaĵoj.',
	'info_non_modifiable' => 'ne modifebla',
	'info_non_suppression_mot_cle' => 'mi ne volas forviŝi tiun ŝlosilvorton.',
	'info_notes' => 'Notoj',
	'info_nouvel_article' => 'Nova artikolo',
	'info_nouvelle_traduction' => 'Nova tradukaĵo :',
	'info_numero_article' => 'ARTIKOLO NUMERO :',
	'info_obligatoire_02' => '(deviga)', # MODIF
	'info_option_accepter_visiteurs' => 'Permesi registriĝojn de vizitantoj el la publika spaco', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Rifuzi registriĝon de vizitantoj', # MODIF
	'info_options_avancees' => 'PLENDETALAJ AGORDOJ',
	'info_ou' => 'aŭ...',
	'info_page_interdite' => 'Malpermesata paĝo',
	'info_par_nom' => 'laŭ nomo',
	'info_par_nombre_article' => 'laŭ nombro de artikoloj',
	'info_par_statut' => 'laŭ statuso',
	'info_par_tri' => '’(laŭ @tri@)’',
	'info_passe_trop_court' => 'Pasvorto tro mallonga.',
	'info_passe_trop_court_car_pluriel' => 'La pasvorto devas enhavi almenaŭ @nb@ signojn.',
	'info_passes_identiques' => 'Ambaŭ pasvortoj ne samas.',
	'info_plus_cinq_car' => 'pli ol 5 signoj',
	'info_plus_cinq_car_2' => '(Pli ol 5 signoj)',
	'info_plus_trois_car' => '(Pli ol 3 signoj)',
	'info_popularite' => 'populareco : @popularite@ ; vizitoj : @visites@',
	'info_post_scriptum' => 'Postskribo',
	'info_post_scriptum_2' => 'Postskribo :',
	'info_pour' => 'por',
	'info_preview_texte' => 'Eblas antaŭrigardi la diversajn redakteblajn elementojn, kiuj havas almenaŭ la statuson „Proponita“, kaj ankaŭ la elementojn, kiujn vi estas redaktanta. Ĉu tio eblu nur al mastrumantoj, al ĉiuj redaktantoj, aŭ al neniu ?', # MODIF
	'info_procedez_par_etape' => 'procedu etapon post etapo',
	'info_procedure_maj_version' => 'la ĝisdatiga proceduro devas esti lanĉita por adapti
 la datenbazon al la nova versio de SPIP.',
	'info_proxy_ok' => 'Testo de la prokurservilo sukcesa.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publikigi',
	'info_publies' => 'Viaj artikoloj rete publikigitaj',
	'info_question_accepter_visiteurs' => 'Se viaj skeletoj ebligas registradon de vizitantoj, kiuj ne rajtas aliri la privatan spacon, bonvolu aktivigi la ĉi-suban opcion :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Ĉu vi akceptas la registriĝadon de novaj redaktantoj ekde
  la publika spaco ? Se vi akceptas tion, la vizitantoj povos registriĝi
  per aŭtomata aliĝilo kaj tiam aliros al la privata spaco por
  proponi siajn proprajn artikolojn. <div class="notice">Dum la aliĝo,
  la uzantoj ricevos aŭtomate senditan retmesaĝon kun siaj
  alir-kodoj al la privata spaco. Iuj
  retejgastigantoj malaktivigas la sendadon de retleteroj el siaj
  serviloj : tiukaze la aŭtomata aliĝo ne eblos.</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ laboris pri tiu ĉi enhavo antaŭ @date_diff@ minutoj',
	'info_racine_site' => 'Radiko de la retejo',
	'info_recharger_page' => 'Bonvolu refreŝigi tiun ĉi paĝon post momento.',
	'info_recherche_auteur_zero' => 'Neniu rezulto por "@cherche_auteur@".',
	'info_recommencer' => 'Bonvolu rekomenci.',
	'info_redacteur_1' => 'Redaktanto',
	'info_redacteur_2' => 'kun aliro al la privata spaco (<i>Estas konsilinde</i>)',
	'info_redacteurs' => 'Redaktantoj',
	'info_redaction_en_cours' => 'REDAKTATA',
	'info_redirection' => 'Alidirektigo',
	'info_redirection_activee' => 'La alidirektigo estas aktiva.',
	'info_redirection_boucle' => 'Vi provas redirekti la artikolo al ĝi mem.',
	'info_redirection_desactivee' => 'La alidirektigo estis forigita.',
	'info_refuses' => 'Viaj rifuzitaj artikoloj',
	'info_reglage_ldap' => 'Opcioj : <b>Agordo de la LDAP-elŝuto</b>',
	'info_renvoi_article' => '<b>Alidirektigo.</b> Tiu artikolo alidirektas al la paĝo :',
	'info_reserve_admin' => 'Nur la mastrumantoj povas modifi tiun ĉi adreson.', # MODIF
	'info_restreindre_rubrique' => 'Limigi la mastrumadon al la rubriko :',
	'info_resultat_recherche' => 'Serĉo-rezultoj :',
	'info_rubriques' => 'Rubrikoj',
	'info_rubriques_02' => 'rubrikoj',
	'info_rubriques_trouvees' => 'Trovitaj rubrikoj',
	'info_sans_titre' => 'Sen titolo',
	'info_selection_chemin_acces' => '<b>Selektu</b> ĉi-sube alirvojon en la dosierujilo :',
	'info_signatures' => 'subskriboj',
	'info_site' => 'Retejo',
	'info_site_2' => 'retejo :',
	'info_site_min' => 'retejo',
	'info_site_reference_2' => 'Referencigita retejo',
	'info_site_web' => 'Retejo :',
	'info_sites' => 'retejoj',
	'info_sites_lies_mot' => 'La referencigitaj retejoj ligitaj al tiu ĉi ŝlosilvorto',
	'info_sites_proxy' => 'Uzi prokuran servilon',
	'info_sites_trouves' => 'Retejoj trovitaj',
	'info_sous_titre' => 'Subtitolo :',
	'info_statut_administrateur' => 'Mastrumanto', # MODIF
	'info_statut_auteur' => 'Statuso de tiu ĉi aŭtoro :',
	'info_statut_auteur_2' => 'Mi estas',
	'info_statut_auteur_a_confirmer' => 'Konfirmenda registropeto',
	'info_statut_auteur_autre' => 'Alia statuso :',
	'info_statut_redacteur' => 'Redaktanto',
	'info_statut_utilisateurs_1' => 'Defaŭlta statuso de la importitaj uzantoj', # MODIF
	'info_statut_utilisateurs_2' => 'Elektu la statuson atribuotan al la personoj ĉeestantaj en LDAP-dosierujilo, kiam ili unuafoje konektiĝas. Poste vi povos modifi tiun valoron por ĉiu aŭtoro laŭkaze.', # MODIF
	'info_suivi_activite' => 'Superrigardo de la redakta agado',
	'info_surtitre' => 'Surtitolo :',
	'info_syndication_integrale_1' => 'Via retejo proponas abondosierojn (vidu « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Ĉu vi deziras transdoni tutajn artikolojn, aŭ nur afiŝi kelkcent-literan resumon ?',
	'info_table_prefix' => 'Vi povas modifi la prefikson de la datentabelo (tio nepras se vi deziras instali plurajn retejojn en la sama datenbazo). Tiun prefikson skribu per minusklaj literoj, sen ĉapeloj, kaj sen spaco.',
	'info_taille_maximale_images' => 'SPIP tuj pritestos la maksimuman bildgrandecon, kiun ĝi povas pritrakti (laŭ milionrastrumeroj). <br/> La plej grandaj bildoj ne estos malgrandigitaj.',
	'info_taille_maximale_vignette' => 'Maksimuma grandeco de la vinjetoj generataj de la sistemo :',
	'info_terminer_installation' => 'Vi povas nun fini laŭnorman instalproceduron.',
	'info_texte' => 'Teksto',
	'info_texte_explicatif' => 'Klariga teksto',
	'info_texte_long' => '(la teksto estas longa : ĝi aperas do en pluraj partoj kiuj estos rekunigitaj post validigo.)',
	'info_texte_message' => 'Teksto de via mesaĝo',
	'info_texte_message_02' => 'Teksto de la mesaĝo',
	'info_titre' => 'Titolo :',
	'info_total' => 'totalo :',
	'info_tous_articles_en_redaction' => 'Ĉiuj artikoloj redaktataj',
	'info_tous_articles_presents' => 'Ĉiuj artikoloj publikigitaj en tiu ĉi rubriko',
	'info_tous_articles_refuses' => 'Ĉiuj artikoloj rifuzitaj',
	'info_tous_les' => 'ĉiuj :',
	'info_tout_site' => 'La tuta retejo',
	'info_tout_site2' => 'La artikolon oni ne tradukis al tiu lingvo.',
	'info_tout_site3' => 'La artikolo jam haveblas en tiu lingvo, sed modifoj estis poste aldonitaj al la referenca artikolo. Bonvolu ĝisdatigi la tradukaĵon.',
	'info_tout_site4' => 'La artikolo haveblas en tiu lingvo, kaj la tradukaĵo estas ĝisdatigita.',
	'info_tout_site5' => 'Originala artikolo.',
	'info_tout_site6' => '<b>Atentu :</b> nur la originalaj artikoloj estas afiŝitaj.
La tradukoj estas kunligitaj al la originalo, kun koloro kiu indikas ties staton :',
	'info_traductions' => 'Tradukoj',
	'info_travail_colaboratif' => 'Kunlaborado pri la artikoloj',
	'info_un_article' => 'unu artikolo,',
	'info_un_site' => 'retejo,',
	'info_une_rubrique' => 'unu rubriko,',
	'info_une_rubrique_02' => '1 rubriko',
	'info_url' => 'URL :',
	'info_url_proxy' => 'URL de la prokura servilo',
	'info_url_proxy_pas_conforme' => 'la retadreso (URL) de la prokura servilo ne validas.',
	'info_url_site_pas_conforme' => 'la retadreso (URL) de la retejo ne validas.',
	'info_url_test_proxy' => 'URL de testo',
	'info_urlref' => 'Hiperligilo :',
	'info_utilisation_spip' => 'Vi povas nun ekuzi la asistatan publikigilon...',
	'info_visites_par_mois' => 'Afiŝado laŭ monato :',
	'info_visiteur_1' => 'Vizitanto',
	'info_visiteur_2' => 'de la publika spaco',
	'info_visiteurs' => 'Vizitantoj',
	'info_visiteurs_02' => 'Vizitantoj de la publika spaco',
	'info_webmestre_forces' => 'La retejestroj nune estas difinita en <tt>@file_options@</tt>.', # MODIF
	'install_adresse_base_hebergeur' => 'Adreso de la datenbazo atribuita de la retejgastiganto',
	'install_connect_ok' => '﻿﻿﻿﻿La nova bazo estis bone deklarita kiel servilonomo @connect@.',
	'install_echec_annonce' => 'Certe la instalado estas malsukcesonta, aŭ naskos ne funkciivan retejon...',
	'install_extension_mbstring' => 'SPIP ne funkcias per :',
	'install_extension_php_obligatoire' => 'SPIP postulas la php-kromprogramon :',
	'install_login_base_hebergeur' => 'Salutnomo atribuita de la retejgastiganto',
	'install_nom_base_hebergeur' => 'Baznomo atribuita de la retejgastiganto :',
	'install_pas_table' => 'Tiu ĉi datumbazo nune enhavas neniun tabelo',
	'install_pass_base_hebergeur' => 'Pasvorto atribuita de la retejgastiganto',
	'install_php_version' => 'PHP-versio @version@ eksnuna (minimuma = @minimum@)',
	'install_select_langue' => 'Elektu lingvon kaj poste musklaku la butonon « sekvanta » por lanĉi la instal-proceduron.',
	'install_select_type_db' => 'Indiku la datumbazan tipon :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servilo de datumbazo atribuita de la retgastiganto',
	'install_table_prefix_hebergeur' => 'Prefikso de la tabelo atribuita de la retejgastiganto :',
	'install_tables_base' => 'Tabeloj de la datumbazo',
	'install_types_db_connus' => 'SPIP scipovas uzi <b>MySQL</b> (la plej kutime uzatan) kaj <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'La uzado de <b>PostgreSQL</b> estas ankaŭ proponita kiel eksperimenta',
	'instituer_erreur_statut_a_change' => 'La statuso jam estis modifita',
	'instituer_erreur_statut_non_autorise' => 'Vi ne povas elekti tiun statuson',
	'intem_redacteur' => 'redaktanto',
	'intitule_licence' => 'Licenco',
	'item_accepter_inscriptions' => 'Akcepti la registropetojn',
	'item_activer_messages_avertissement' => 'Aktivigi la averto-mesaĝojn',
	'item_administrateur_2' => 'mastrumanto', # MODIF
	'item_afficher_calendrier' => 'Afiŝi en la kalendaro',
	'item_autoriser_syndication_integrale' => 'Disponigi la tuton de la artikoloj en la abondosieroj',
	'item_choix_administrateurs' => 'la mastrumantoj', # MODIF
	'item_choix_generation_miniature' => 'Aŭtomatigi miniaturigadon de la bildoj.',
	'item_choix_non_generation_miniature' => 'Ne generi bildajn miniaturojn.',
	'item_choix_redacteurs' => 'la redaktantoj',
	'item_choix_visiteurs' => 'la vizitantoj de la publika spaco',
	'item_creer_fichiers_authent' => 'Krei la dosierojn .htpasswd',
	'item_login' => 'Salutnomo',
	'item_messagerie_agenda' => 'Aktivigi la mesaĝilon kaj la agendon',
	'item_mots_cles_association_articles' => 'al artikoloj',
	'item_mots_cles_association_rubriques' => 'al rubrikoj',
	'item_mots_cles_association_sites' => 'al referencigitaj aŭ abonligitaj retejoj.',
	'item_non' => 'Ne',
	'item_non_accepter_inscriptions' => 'Ne akcepti la registropetojn',
	'item_non_activer_messages_avertissement' => 'Neniuj averto-mesaĝoj',
	'item_non_afficher_calendrier' => 'Ne afiŝi en la kalendaro',
	'item_non_autoriser_syndication_integrale' => 'Nur disponigi po unu resumo',
	'item_non_creer_fichiers_authent' => 'Ne krei tiujn ĉi dosierojn',
	'item_non_messagerie_agenda' => 'Malaktivigi la mesaĝilon kaj la agendon',
	'item_non_publier_articles' => 'Ne publikigi la artikolojn antaŭ la fiksita publikig-dato.',
	'item_nouvel_auteur' => 'Nova aŭtoro',
	'item_nouvelle_rubrique' => 'Nova rubriko',
	'item_oui' => 'Jes',
	'item_publier_articles' => 'Publikigi la artikolojn, kiu ajn estas ties publikig-dato.',
	'item_reponse_article' => 'Respondo al la artikolo',
	'item_visiteur' => 'vizitanto',

	// J
	'jour_non_connu_nc' => 'ne konata',

	// L
	'label_bando_outils' => 'Ilobreto',
	'label_bando_outils_afficher' => 'Afiŝi la ilojn',
	'label_bando_outils_masquer' => 'Kaŝi la ilojn',
	'label_choix_langue' => 'Elektu vian lingvon',
	'label_nom_fichier_connect' => 'Indiku la nomon uzita por tiu servilo',
	'label_slogan_site' => 'Devizo de la retejo',
	'label_taille_ecran' => 'Larĝo de la ekrano',
	'label_texte_et_icones_navigation' => 'Naviga menuo',
	'label_texte_et_icones_page' => 'Afiŝado en paĝo',
	'ldap_correspondance' => 'heredado de la kampo @champ@',
	'ldap_correspondance_1' => 'Heredadoj de LDAP-kampoj',
	'ldap_correspondance_2' => 'Por ĉiuj jenaj SPIP-kampoj, indiki la nomo de la rilata LDAP-kampo. Lasi malplenan por ne plenigis ĝin, apartigi per spacoj aŭ komoj por provi plurajn LDAP-kampoj.',
	'lien_ajouter_auteur' => 'Aldoni tiun aŭtoron',
	'lien_ajouter_une_rubrique' => 'Aldoni tiu rubriko',
	'lien_email' => 'retpoŝtadreso',
	'lien_nom_site' => 'NOMO DE LA RETEJO :',
	'lien_rapide_contenu' => 'Iri al la enhavo',
	'lien_rapide_navigation' => 'Iri al la navigado',
	'lien_rapide_recherche' => 'Iri al la serĉo',
	'lien_retirer_auteur' => 'Forviŝi la aŭtoron',
	'lien_retirer_rubrique' => 'Forviŝi la rubrikon',
	'lien_retirer_tous_auteurs' => 'Forviŝi ĉiujn aŭtorojn',
	'lien_retirer_toutes_rubriques' => 'Forviŝi ĉiujn rubrikojn',
	'lien_site' => 'retejo',
	'lien_tout_decocher' => 'Ĉion malmarki',
	'lien_tout_deplier' => 'Malfaldi ĉion',
	'lien_tout_replier' => 'Refaldi ĉion',
	'lien_tout_supprimer' => 'Ĉion forviŝi',
	'lien_trier_nom' => 'Vicigi laŭ nomo',
	'lien_trier_nombre_articles' => 'Vicigi laŭ nombro de artikoloj',
	'lien_trier_statut' => 'Vicigi laŭ statuso',
	'lien_voir_en_ligne' => 'VIDI ĈERETIGITE :',
	'logo_article' => 'Vinjeto de la artikolo',
	'logo_auteur' => 'Vinjeto de la aŭtoro',
	'logo_rubrique' => 'Vinjeto de la rubriko',
	'logo_site' => 'Vinjeto de la retejo
',
	'logo_standard_rubrique' => 'Laŭnorma vinjeto de rubrikoj',
	'logo_survol' => 'Vinjeto por flugrigardo',

	// M
	'menu_aide_installation_choix_base' => 'Elekto de via datenbazo',
	'module_fichier_langue' => 'Lingva dosiero',
	'module_raccourci' => 'Rapid-alirilo',
	'module_texte_affiche' => 'Afiŝita teksto',
	'module_texte_explicatif' => 'Vi povas inkludi la jenajn rapid-klakeblojn en la skeletojn de via publika retejo. Ili estos aŭtomate tradukitaj en la diversajn lingvojn, kiuj havas specifan lingvan dosieron.',
	'module_texte_traduction' => 'La lingva dosiero « @module@ » disponeblas en :',
	'mois_non_connu' => 'nekonata',

	// N
	'nouvelle_version_spip' => 'La SPIP-ĝisdatigo @version@ estas disponebla',
	'nouvelle_version_spip_majeure' => 'Nova SPIP-versio @version@ disponeblas',

	// O
	'onglet_contenu' => 'Enhavo',
	'onglet_declarer_une_autre_base' => 'Deklari alian datumbazon',
	'onglet_discuter' => 'Diskuti',
	'onglet_interactivite' => 'Interago',
	'onglet_proprietes' => 'Trajtoj',
	'onglet_repartition_actuelle' => 'nun',
	'onglet_sous_rubriques' => 'Subrubrikoj',

	// P
	'page_pas_proxy' => 'Tiu ĉi paĝo ne ŝutiĝu tra la prokura servilo',
	'pas_de_proxy_pour' => 'Laŭbezone, indiku komputilojn aŭ domajnojn por kiuj tiu prokurservilo ne devas aplikiĝi (ekzemple : @exemple@)',
	'phpinfo' => 'PHP-agordo',
	'plugin_charge_paquet' => 'Ŝargado de la pakaĵo @name@',
	'plugin_charger' => 'Elŝuti',
	'plugin_erreur_charger' => 'eraro : ne eblas ŝargi @zip@',
	'plugin_erreur_droit1' => 'La dosierujo <code>@dest@</code> ne estas skribe alirebla.',
	'plugin_erreur_droit2' => 'Bonvolu kontroli la rajtojn pri tiu ĉi dosierujo (kaj krei ĝin laŭkaze), aŭ instali la dosierojn per FTP.',
	'plugin_erreur_zip' => 'malsukceso pclzip : eraro @status@',
	'plugin_etat_developpement' => 'disvolvata',
	'plugin_etat_experimental' => 'eksperimenta',
	'plugin_etat_stable' => 'stabila',
	'plugin_etat_test' => 'testata',
	'plugin_impossible_activer' => 'Ne eblas aktivigi la kromprogramon @plugin@',
	'plugin_info_automatique1' => 'Se vi deziras permesi la aŭtomatan instaladon de kromprogramoj, bonvolu :',
	'plugin_info_automatique1_lib' => 'Se vi deziras permesi aŭtomata instalado de tiu biblioteko, bonvolu :',
	'plugin_info_automatique2' => 'krei dosierujon <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'kontroli ke estas permesate al la servilo skribi en tiu ĉi dosierujo.',
	'plugin_info_automatique_creer' => 'kreenda ĉe la reteja radiko.',
	'plugin_info_automatique_exemples' => 'ekzemploj :',
	'plugin_info_automatique_ftp' => 'Vi povas instali kromprogramojn, per FTP, en la dosierujon <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Iuj kromprogramoj postulas ankaŭ la eblon elŝuti dosierojn en la dosierujon <code>lib/</code>. Tiu dosierujo estas laŭkaze kreenda ĉe la reteja radiko.',
	'plugin_info_automatique_liste' => 'Viaj listoj de kromprogramoj :',
	'plugin_info_automatique_liste_officielle' => 'la oficialaj kromprogramoj',
	'plugin_info_automatique_liste_update' => 'Ĝisdatigi la listojn',
	'plugin_info_automatique_ou' => 'aŭ...',
	'plugin_info_automatique_select' => 'Elektu ĉi-sube kromprogramon : SPIP elŝutos ĝin kaj instalos ĝin en la dosierujo <code>@rep@</code> ; se tiu ĉi kromprogramo jam ekzistas, ĝi estos ĝisdatigita.',
	'plugin_info_credit' => 'Kreditoj',
	'plugin_info_erreur_xml' => 'Deklaro de tiu kromprogramo ne ĝustas',
	'plugin_info_install_ok' => 'Sukcesa instalado',
	'plugin_info_necessite' => 'Necesas :',
	'plugin_info_non_compatible_spip' => 'Tiu ĉi kromprogramo ne estas kongrua kun tiu SPIP-versio',
	'plugin_info_plugins_dist_1' => 'Kromprogramoj ĉi-sube estas ŝarĝitaj kaj aktivigitaj en la dosierujo @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'Ili ne malaktivigas.',
	'plugin_info_telecharger' => 'elŝutota de @url@ kaj instalota en @rep@',
	'plugin_info_upgrade_ok' => 'Sukcesa ĝisdatigo',
	'plugin_librairies_installees' => 'Instalitaj bibliotekoj',
	'plugin_necessite_extension_php' => 'Postulas la PHP-kromprogramon @plugin@ laŭ versio @version@.',
	'plugin_necessite_extension_php_sans_version' => 'Postulas la PHP-kromprogramon @plugin@',
	'plugin_necessite_lib' => 'Tiu ĉi kromprogramo bezonas la bibliotekon @lib@',
	'plugin_necessite_php' => 'Postulas @plugin@ laŭ versio @version@.',
	'plugin_necessite_plugin' => 'Postulas la kromprogramon @plugin@ laŭ versio @version@.',
	'plugin_necessite_plugin_sans_version' => 'Necesas la kromprogramon @plugin@',
	'plugin_necessite_spip' => 'Necesas SPIP laŭ minimume versio @version@.',
	'plugin_source' => 'fonto : ',
	'plugin_titre_automatique' => 'Aŭtomata instalo',
	'plugin_titre_automatique_ajouter' => 'Aldoni kromprogramojn',
	'plugin_titre_installation' => 'Instalado de la kromprogramo @plugin@',
	'plugin_titre_modifier' => 'Miaj kromprogramoj',
	'plugin_utilise_extension_php' => 'Uzas la PHP-kromprogramon @plugin@ laŭ versio @version@.', # MODIF
	'plugin_utilise_php' => 'Uzas @plugin@ laŭ versio @version@.', # MODIF
	'plugin_utilise_plugin' => 'Uzas la kromprogramon @plugin@ de versio @version@.', # MODIF
	'plugin_zip_active' => 'Daŭrigu por ĝin aktivigi',
	'plugin_zip_adresse' => 'indiku ĉi-sube la retadreson de la maldensa dosiero de elŝutenda kromprogramo, aŭ la retadreson de kromprogramolisto.',
	'plugin_zip_adresse_champ' => 'Retadreso de la kromprogramo aŭ de la listo ',
	'plugin_zip_content' => 'Ĝi enhavas la jenajn dosierojn (@taille@),
<br />pretajn por instali en la dosierujo <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'La dosiero @zip@ estis ekstraktita kaj instalita.',
	'plugin_zip_installe_rep_finie' => 'La dosiero @zip@ estis ekstraktita kaj instalita en la dosierujo @rep@',
	'plugin_zip_installer' => 'Vi nun povas instali ĝin',
	'plugin_zip_telecharge' => 'La dosiero @zip@ estis elŝutita',
	'plugins_actif_aucun' => 'Neniu aktivata kromprogramo.',
	'plugins_actif_un' => 'Unu aktivata kromprogramo.',
	'plugins_actifs' => '@count@ aktivataj kromprogramoj.',
	'plugins_actifs_liste' => 'Aktivaj',
	'plugins_compte' => '@count@ kromprogramoj',
	'plugins_disponible_un' => 'Unu disponebla kromprogramo.',
	'plugins_disponibles' => '@count@ disponeblaj kromprogramoj.',
	'plugins_erreur' => 'Eraro en la kromprogramoj : @plugins@',
	'plugins_liste' => 'Listo de kromprogramoj',
	'plugins_liste_dist' => 'Ŝlositaj kromprogramoj',
	'plugins_recents' => 'Freŝaj kromprogramoj.',
	'plugins_tous_liste' => 'Ĉiuj',
	'plugins_vue_hierarchie' => 'Hierarkio',
	'plugins_vue_liste' => 'Listo',
	'protocole_ldap' => 'Protokolversio :',

	// Q
	'queue_executer_maintenant' => 'Lanĉi nun',
	'queue_info_purger' => 'Vi povas forviŝi ĉiujn atendante taskojn kaj restarigi la liston kun la periodaj taskoj', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ atendante taskoj', # MODIF
	'queue_next_job_in_nb_sec' => 'Sekva tasko post @nb@ s', # MODIF
	'queue_no_job_in_queue' => 'Neniu atendante tasko', # MODIF
	'queue_one_job_in_queue' => '1 atendante tasko', # MODIF
	'queue_priorite_tache' => 'prioritato',
	'queue_purger_queue' => 'Restarigi la taskliston', # MODIF
	'queue_titre' => 'Tasklisto', # MODIF

	// R
	'repertoire_plugins' => 'Dosierujo :',
	'required' => '(deviga)', # MODIF

	// S
	'sans_heure' => 'sen horo',
	'statut_admin_restreint' => '(limigita mastrumanto)',
	'statut_webmestre' => 'retejestro',

	// T
	'tache_cron_asap' => 'Tasko CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tasko CRON @function@ (ĉiuj @nb@ s)',
	'taille_cache_image' => 'La bildoj aŭtomate komputitaj de SPIP (vijnetoj de dokumentoj, titoloj prezentitaj laŭ grafika formo, matematikaj funkcioj laŭ TeX-formato...) okupas en dosierujo @dir@ spacon je @taille@.',
	'taille_cache_moins_de' => 'Memorspaco de la staplo estas malpli ol @octets@.',
	'taille_cache_octets' => 'Memorspaco de la staplo estas nun proksimume @octets@.',
	'taille_cache_vide' => 'La staplo estas malplena.',
	'taille_repertoire_cache' => 'Memorspaco de stapla dosierujo',
	'text_article_propose_publication' => 'Artikolo proponita por publikigo.',
	'texte_acces_ldap_anonyme_1' => 'Iuj LDAP-serviloj ne akceptas sennoman aliron. Tiukaze, necesas difini identecnomon por serĉi informojn en dosierujilo. Plejofte tamen, la sekvantaj tajpujoj povas resti malplenaj.',
	'texte_admin_effacer_01' => 'Tiu komando forviŝas <i>la tutan</i> enhavon de la datenbazo,
inkluzive de <i>ĉiuj</i> alirrajtoj de redaktantoj kaj mastrumantoj. Post ties efektivigo, vi devos lanĉi la
SPIP-reinstalon por rekrei novan bazon kaj unuan mastrumulan alirrajton.', # MODIF
	'texte_adresse_annuaire_1' => '(Se via adresaro estas instalita ĉe la sama maŝino kiel la retejo, temas verŝajne pri « localhost ».)',
	'texte_ajout_auteur' => 'La jena aŭtoro estis aldonita al la artikolo :',
	'texte_annuaire_ldap_1' => 'Se vi havas aliron al dosierujilo (LDAP), vi povas uzi ĝin por aŭtomate importi uzantojn sub SPIP.', # MODIF
	'texte_article_statut' => 'Tiu artikolo estas :',
	'texte_article_virtuel' => 'Virtuala artikolo',
	'texte_article_virtuel_reference' => '<b>Virtuala artikolo :</b> artikolo referencigita ĉe via SPIP-retejo, sed alidirektita al alia retadreso. Por forigi la alidirekton, forviŝu la ĉi supran URL-n.',
	'texte_aucun_resultat_auteur' => 'Neniu rezulto por "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Tiu retejo povas konstante indiki la liston de la konektitaj redaktantoj. Tio ebligas al vi rekte interŝanĝi mesaĝojn. Vi povas decidi ne aperi en tia listo (vi estas « nevidebla » al la aliaj uzantoj).', # MODIF
	'texte_auteurs' => 'LA AŬTOROJ',
	'texte_choix_base_1' => 'Elektu vian datenbazon :',
	'texte_choix_base_2' => 'La SQL-servilo enhavas plurajn datenbazojn.',
	'texte_choix_base_3' => '<b>Elektu</b> ĉi-poste tiun, kiun atribuis al vi via retejgastiganto :',
	'texte_choix_table_prefix' => 'Prefikso de la tabeloj :',
	'texte_compte_element' => '@count@ elemento',
	'texte_compte_elements' => '@count@ elementoj',
	'texte_conflit_edition_correction' => 'Bonvolu kontroli ĉi-sube la diferencojn inter ambaŭ versioj de la teksto, vi povas ankaŭ kopii viajn ŝanĝojn, poste restartu.',
	'texte_connexion_mysql' => 'Konsultu la informojn donitajn de via retgastiganto : en ili, vi trovos la ensalutilojn necesajn por konektiĝi al la servilo de datumbazo kiun li proponas.',
	'texte_contenu_article' => '(Kelkvorta enhavo-priskribo de la artikolo.)',
	'texte_contenu_articles' => 'Laŭ la modelo adoptita por via retejo, vi povas decidi
  ke certaj elementoj de la artikoloj ne estu uzataj.
  Uzu la ĉi-suban liston por indiki kiuj elementoj disponeblas.',
	'texte_crash_base' => 'Se via datenbazo kolapsis,
   vi povas provi
   aŭtomatan riparon.',
	'texte_creer_rubrique' => 'Antaŭ ol povi skribi artikolojn,<br /> vi devas krei rubrikon.',
	'texte_date_creation_article' => 'KREO-DATO DE LA ARTIKOLO :',
	'texte_date_creation_objet' => 'Kreo-dato :', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'DATO DE ANTAŬA REDAKTO :',
	'texte_date_publication_anterieure_nonaffichee' => 'Ne afiŝi daton de antaŭa redakto.',
	'texte_date_publication_article' => 'DATO DE RETA PUBLIKIGO :',
	'texte_date_publication_objet' => 'Dato de reta publikigo :',
	'texte_definir_comme_traduction_rubrique' => 'Tiu rubriko estas traduko de la rubriko numero :',
	'texte_descriptif_rapide' => 'Konciza priskribo',
	'texte_effacer_base' => 'Forviŝi la SPIP-datenbazon',
	'texte_effacer_statistiques' => 'Forviŝi statistikojn',
	'texte_en_cours_validation' => 'La enhavoj ĉi-subaj estas proponitaj por publikigo.',
	'texte_enrichir_mise_a_jour' => 'Vi povas pliriĉigi la enpaĝigon de via teksto uzante « tipografiajn rapidklavojn ».',
	'texte_fichier_authent' => '<b>Ĉu SPIP kreu la specialajn dosierojn <tt>.htpasswd</tt> kaj <tt>.htpasswd-admin</tt> en dosierujo @dossier@ ?</b>
<p>Tiuj dosieroj ebligas limigi la alirrajton de aŭtoroj kaj administrantoj en aliaj lokoj de via retejo (ekzemple, ekstera statistik-programo).</p>
<p>Se tio ne utilas al vi, vi povas lasi tiun opcion je ĝia defaŭlta valoro (neniu dosier-kreo).</p>', # MODIF
	'texte_informations_personnelles_1' => 'La sistemo kreos por vi nun personan alireblon al la retejo.',
	'texte_informations_personnelles_2' => '(Noto : se temas pri reinstalo kaj se via aliro daŭre funkcias, vi povas',
	'texte_introductif_article' => '(Enkonduka teksto al la artikolo.)',
	'texte_jeu_caractere' => 'Ni konsilas al vi uzi, en via retejo, universalan alfabeton (<tt>utf-8</tt>) : tio ebligas afiŝadon de tekstoj en ĉiuj lingvoj kaj solvas problemojn de kongrueco se vi uzas modernajn retumilojn.',
	'texte_jeu_caractere_3' => 'Via retejo estas nun instalita laŭ la litertiparo :',
	'texte_jeu_caractere_4' => 'Se tio ne kongruas kun la realo de viaj datenoj (ekzemple, sekve de datenbazo-restaŭro), aŭ se <em>vi ĵus ekkreis tiun retejon</em> kaj deziras ekuzi novan litertiparon, bonvolu indiki ĝin ĉi tie :',
	'texte_login_ldap_1' => 'Lasu malplena por sennoma aliro, aŭ entajpu la kompletan vojon, ekzemple « <tt>uid=nomo, ou=uzanto, dc=mia-domajno, dc=com</tt> ».)',
	'texte_login_precaution' => 'Atentu ! Tio ĉi estas la salutnomo laŭ kiu vi ensalutis.
 Uzu tiun ĉi formularon prudente...',
	'texte_messagerie_agenda' => 'Mesaĝado permesas al retejaj redaktantoj komuniki inter si rekte en la privata spaco de la retejo. Ĝi estas asociita kun agendo.', # MODIF
	'texte_mise_a_niveau_base_1' => 'Vi ĵus ĝisdatigis la SPIP-dosierojn.
 Necesas nun alniveligi la datenbazon
 de la retejo.',
	'texte_modifier_article' => 'Modifi la artikolon :',
	'texte_multilinguisme' => 'Se vi deziras mastrumi la objektojn en pluraj lingvoj, per kompleksa retumado, vi povas aldoni menuon pri lingvoelekto en la objektojn, konforme al la organizo de via retejo.',
	'texte_multilinguisme_trad' => 'Vi povas ankaŭ aktivigi sistemon por mastrumi la ligilojn inter la diversaj tradukoj sur iuj objektoj.',
	'texte_non_compresse' => '<i>ne densigita</i> (ĉar via servilo ne eltenas tiun funkcion)',
	'texte_nouvelle_version_spip_1' => 'Vi instalis novan version de SPIP.',
	'texte_nouvelle_version_spip_2' => 'Tiu ĉi nova versio bezonas pli kompletan ĝisdatigon ol kutime. Se vi estas retejestro de la retejo, bonvolu forviŝi la dosieron @connect@ kaj restarigi la instalprocezon por ĝisdatigi viajn konekt-parametrojn al la datenbazo.<p> (Notu : se vi forgesis viajn konektparametrojn, legu la dosieron @connect@ antaŭ ol forviŝi ĝin...)</p>',
	'texte_operation_echec' => 'Reiru al antaŭa paĝo, selektu alian datenbazon aŭ kreu novan. Kontrolu la informojn donitajn de via retgastiganto.',
	'texte_plus_trois_car' => 'pli ol 3 literoj',
	'texte_plusieurs_articles' => 'Pluraj aŭtoroj trovitaj por"@cherche_auteur@" :',
	'texte_port_annuaire' => 'La defaŭlte indikita valoro ĝenerale taŭgas.)',
	'texte_presente_plugin' => 'Tiu paĝo listigas kromprogramojn disponeblajn ĉe tiu retejo. Vi povas aktivigi la necesajn kromprogramojn noĉante la kongruan noĉujon.',
	'texte_proposer_publication' => 'Kiam via artikolo estas finita,<br /> vi povas proponi ĝian publikigon.',
	'texte_proxy' => 'En iuj okazoj (intrareto, protektitaj retoj...),
  povas esti necese uzi na <i>proxy HTTP</i> por atingi eksterajn retejojn (dokumentaron de SPIP, abonligitajn retejojn, ktp...).
  Se tio okazas, indiku ĉi-sube ties retadreson, laŭ la formo @proxy_en_cours@. Ĝenerale,
  lasu tiun tajpujon malplena.',
	'texte_publication_articles_post_dates' => 'Kiel kondutu SPIP rilate la artikolojn
  kies publikig-dato estis fiksita
  por estonta templimo ?',
	'texte_rappel_selection_champs' => '[Ne forgesu ĝuste selekti tiun kampon.]',
	'texte_recalcul_page' => 'Se vi volas
rekalkuli ununuran paĝon, pasu prefere tra la publika spaco kaj tie uzu la butonon « rekalkuli ».',
	'texte_recuperer_base' => 'Ripari la datenbazon',
	'texte_reference_mais_redirige' => 'artikolo referencigita ĉe via SPIP-retejo, sed redirektita al alia URL.',
	'texte_requetes_echouent' => '<b>Kiam iuj SQL-serĉpetoj ĉiufoje
kaj senkiale malsukcesas, estas eble
ke tio okazas pro la datenbazo
mem.</b><p>
Via SQL-servilo disponas je ripar-kapablo de siaj
tabeloj kiam ili estas akcidente difektitaj.
Vi povas ĉi tie provi riparon ;
en kazo de malsukceso, faru ekrankopion.
Ĝi eble entenas indicojn pri la misfunkcio...</p><p>
Se la problemo daŭras, kontaktu
vian retgastiganton.</p>',
	'texte_selection_langue_principale' => 'Vi povas ĉi-sube elekti la « ĉefan lingvon » de la retejo. Tiu elekto ne devigas vin - bonŝance ! - verki viajn artikolojn en la elektita lingvo, sed ebligas determini :
 <ul><li> la defaŭltan formaton de la datenoj en la publika spaco ;</li>
 <li> kian tipografiilon SPIP devas uzi pri tekst-aspektigo ;</li>
 <li> la lingvon uzendan en la formularoj de la publika spaco ;</li>
 <li> la lingvon defaŭlte prezentitan en la privata spaco.</li></ul>',
	'texte_sous_titre' => 'Subtitolo',
	'texte_statistiques_visites' => '(Malhelaj stangoj : dimanĉo / malhela kurbo : evoluo de la meznombro)',
	'texte_statut_attente_validation' => 'Atendantaj validigon',
	'texte_statut_publies' => 'Rete publikigitaj',
	'texte_statut_refuses' => 'rifuzitaj',
	'texte_suppression_fichiers' => 'Uzu tiun ĉi komandon por forigi ĉiujn dosierojn troviĝantajn
en la SPIP-staplo. Tio ebligas ekzemple devigi la sistemon rekalkuli ĉiujn paĝojn, se vi
faris gravajn ŝanĝojn en la grafiko aŭ strukturo de la retejo.',
	'texte_sur_titre' => 'Surtitolo',
	'texte_table_ok' => ' : tiu tabelo estas en ordo.',
	'texte_tentative_recuperation' => 'Ripar-provo',
	'texte_tenter_reparation' => 'Provi riparon de la datenbazo',
	'texte_test_proxy' => 'Por testi tiun prokuran servilon, indiku ĉi tie la adreson de retejo, kiun vi deziras testi.',
	'texte_titre_02' => 'Titolo :',
	'texte_titre_obligatoire' => '<b>Titolo</b> [Deviga]',
	'texte_travail_article' => '@nom_auteur_modif@ prilaboris tiun artikolon antaŭ @date_diff@ minutoj',
	'texte_travail_collaboratif' => 'Se pluraj redaktantoj laboras ofte
  pri sama artikolo, la sistemo
  povas afiŝi la ĵus « malfermitajn » artikolojn
  por eviti la sammomentajn modifojn.
  Tiu opcio estas defaŭlte malaktivigita
  por eviti maloportunajn
  averto-mesaĝojn.', # MODIF
	'texte_vide' => 'malplena',
	'texte_vider_cache' => 'Malplenigi la staplon',
	'titre_admin_tech' => 'Teknika bontenado',
	'titre_ajouter_un_auteur' => 'Aldoni aŭtoron',
	'titre_ajouter_un_mot' => 'Aldoni ŝlosilvorton',
	'titre_cadre_afficher_article' => 'Afiŝi la artikolojn',
	'titre_cadre_afficher_traductions' => 'Afiŝi la traduk-staton por tiuj lingvoj :',
	'titre_cadre_ajouter_auteur' => 'ALDONI AŬTORON :',
	'titre_cadre_interieur_rubrique' => 'Ene de la rubriko',
	'titre_cadre_numero_auteur' => 'AŬTORO NUMERO',
	'titre_cadre_numero_objet' => '@objet@ NUMERO :',
	'titre_cadre_signature_obligatoire' => '<b>Subskribo</b> [deviga]<br />',
	'titre_config_contenu_notifications' => 'Avizoj',
	'titre_config_contenu_prive' => 'En la privata spaco',
	'titre_config_contenu_public' => 'Ĉe la publika retejo',
	'titre_config_fonctions' => 'Agordo de la retejo',
	'titre_config_langage' => 'Agordi la lingvon',
	'titre_configuration' => 'Agordo de la retejo',
	'titre_configurer_preferences' => 'Agordi viajn preferojn',
	'titre_configurer_preferences_menus' => 'Agordi viajn preferatajn menuojn',
	'titre_conflit_edition' => 'Konflikto dum redaktado',
	'titre_connexion_ldap' => 'Opcioj : <b>Via konekto LDAP</b>',
	'titre_groupe_mots' => 'GRUPO DE VORTOJ :',
	'titre_identite_site' => 'Identeco de la retejo',
	'titre_langue_article' => 'Lingvo de la artikolo',
	'titre_langue_rubrique' => 'Lingvo de la rubriko',
	'titre_langue_trad_article' => 'LINGVO KAJ TRADUKOJ DE LA ARTIKOLO',
	'titre_les_articles' => 'LA ARTIKOLOJ',
	'titre_messagerie_agenda' => 'Mesaĝilo kaj agendo',
	'titre_naviguer_dans_le_site' => 'Retejumi...',
	'titre_nouvelle_rubrique' => 'Nova rubriko',
	'titre_numero_rubrique' => 'RUBRIKO NUMERO :',
	'titre_page_articles_edit' => 'Modifi : @titre@',
	'titre_page_articles_page' => 'La artikoloj',
	'titre_page_articles_tous' => 'La tuta retejo',
	'titre_page_calendrier' => 'Kalendaro @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Agordo de la retejo',
	'titre_page_delete_all' => 'tuta kaj malfarebla forviŝo',
	'titre_page_recherche' => 'Serĉrezulto @recherche@',
	'titre_page_statistiques_referers' => 'Statistikoj (eniraj ligiloj)',
	'titre_page_upgrade' => 'SPIP-alniveligo',
	'titre_preference_menus_favoris' => 'Preferataj menuoj',
	'titre_publication_articles_post_dates' => 'Publikigo de la postdatitaj artikoloj',
	'titre_reparation' => 'Riparo',
	'titre_suivi_petition' => 'Kontrolo de la petskriboj',
	'tls_ldap' => 'Transŝuta tavolsekureco (TLS) :',
	'trad_article_traduction' => 'Ĉiuj versioj de tiu ĉi artikolo :',
	'trad_delier' => 'Ne plu ligi al ties tradukoj',
	'trad_lier' => 'Tiu artikolo estas traduko de la artikolo numero :',
	'trad_new' => 'Skribi novan tradukon',

	// U
	'utf8_convert_erreur_orig' => 'Eraro : la litertiparo @charset@ ne estas eltenata.',

	// V
	'version' => 'Versio :',
];
